@@ -1,9 +1,10 @@
 '''Utility functions'''
 
 from re import sub
-from urllib.parse import parse_qs, urlencode
+from urllib.parse import parse_qs, quote, unquote
 
-from constructor_io.helpers.exception import HttpException
+from constructor_io.helpers.exception import (ConstructorException,
+                                              HttpException)
 
 
 def throw_http_exception_from_response(response):
@@ -34,7 +35,7 @@ def clean_params(params_obj):
         if isinstance(value, str):
             # Replace non-breaking spaces (or any other type of spaces caught by the regex)
             # - with a regular white space
-            cleaned_params[key] = our_encode_uri_component(value)
+            cleaned_params[key] = unquote(our_encode_uri_component(value))
         elif value is not None:
             cleaned_params[key] = value
 
@@ -46,11 +47,9 @@ def our_encode_uri_component(string):
     if string:
         str_replaced = sub('&', '%26', string)
         parsed_str_obj = parse_qs(f's={str_replaced}')
-        decoded = {
-            "s": sub(r'\s', ' ', parsed_str_obj['s'][0])
-        }
+        decoded = sub(r'\s', ' ', parsed_str_obj['s'][0])
 
-        return urlencode(decoded).split('=')[1]
+        return quote(decoded)
 
     return None
 
@@ -78,7 +77,7 @@ def create_shared_query_params(options, parameters, user_parameters):
                 for key, value in filters.items():
                     query_params[f'filters[{key}]'] = value
             else:
-                raise Exception('filters must be a dictionary')
+                raise ConstructorException('filters must be a dictionary')
 
         if parameters.get('sort_by'):
             query_params['sort_by'] = parameters.get('sort_by')
@@ -98,7 +97,7 @@ def create_shared_query_params(options, parameters, user_parameters):
                 for key, value in fmt_options.items():
                     query_params[f'fmt_options[{key}]'] = value
             else:
-                raise Exception('fmt_options must be a dictionary')
+                raise ConstructorException('fmt_options must be a dictionary')
 
     if user_parameters.get('test_cells'):
         for key, value in user_parameters.get('test_cells').items():
@@ -112,9 +111,12 @@ def create_shared_query_params(options, parameters, user_parameters):
 
     return query_params
 
-def create_request_headers(options, user_parameters):
+def create_request_headers(options, user_parameters=None):
     '''Create request headers shared between modules'''
 
+    if not user_parameters:
+        user_parameters = {}
+
     headers = {}
     security_token = options.get('security_token')
     user_ip = user_parameters.get('user_ip')
